/*
 @licstart  The following is the entire license notice for the JavaScript code in this file.

 The MIT License (MIT)

 Copyright (C) 1997-2020 by Dimitri van Heesch

 Permission is hereby granted, free of charge, to any person obtaining a copy of this software
 and associated documentation files (the "Software"), to deal in the Software without restriction,
 including without limitation the rights to use, copy, modify, merge, publish, distribute,
 sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in all copies or
 substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
 BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

 @licend  The above is the entire license notice for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "Eigen", "index.html", [
    [ "Overview", "index.html", null ],
    [ "Getting started", "GettingStarted.html", null ],
    [ "Extending/Customizing Eigen", "UserManual_CustomizingEigen.html", [
      [ "Extending MatrixBase (and other classes)", "TopicCustomizing_Plugins.html", null ],
      [ "Inheriting from Matrix", "TopicCustomizing_InheritingMatrix.html", null ],
      [ "Using custom scalar types", "TopicCustomizing_CustomScalar.html", null ],
      [ "Matrix manipulation via nullary-expressions", "TopicCustomizing_NullaryExpr.html", [
        [ "Example 1: circulant matrix", "TopicCustomizing_NullaryExpr.html#NullaryExpr_Circulant", null ],
        [ "Example 2: indexing rows and columns", "TopicCustomizing_NullaryExpr.html#NullaryExpr_Indexing", null ]
      ] ],
      [ "Adding a new expression type", "TopicNewExpressionType.html", [
        [ "The setting", "TopicNewExpressionType.html#TopicSetting", null ],
        [ "Getting started", "TopicNewExpressionType.html#TopicPreamble", null ],
        [ "The traits class", "TopicNewExpressionType.html#TopicTraits", null ],
        [ "The expression class", "TopicNewExpressionType.html#TopicExpression", null ],
        [ "The evaluator", "TopicNewExpressionType.html#TopicEvaluator", null ],
        [ "The entry point", "TopicNewExpressionType.html#TopicEntry", null ],
        [ "A simple main function for testing", "TopicNewExpressionType.html#TopicMain", null ]
      ] ]
    ] ],
    [ "General topics", "UserManual_Generalities.html", [
      [ "Porting from Eigen2 to Eigen3", "Eigen2ToEigen3.html", [
        [ "Eigen2 compatibility support", "Eigen2ToEigen3.html#CompatibilitySupport", null ],
        [ "The USING_PART_OF_NAMESPACE_EIGEN macro", "Eigen2ToEigen3.html#Using", null ],
        [ "Dot products over complex numbers", "Eigen2ToEigen3.html#ComplexDot", null ],
        [ "Vector blocks", "Eigen2ToEigen3.html#VectorBlocks", null ],
        [ "Matrix Corners", "Eigen2ToEigen3.html#Corners", null ],
        [ "Coefficient wise operations", "Eigen2ToEigen3.html#CoefficientWiseOperations", null ],
        [ "Triangular and self-adjoint matrices", "Eigen2ToEigen3.html#PartAndExtract", null ],
        [ "Triangular in-place solving", "Eigen2ToEigen3.html#TriangularSolveInPlace", null ],
        [ "Matrix decompositions", "Eigen2ToEigen3.html#Decompositions", null ],
        [ "Linear solvers", "Eigen2ToEigen3.html#LinearSolvers", null ],
        [ "Changes in the Geometry module", "Eigen2ToEigen3.html#GeometryModule", null ],
        [ "The Transform class", "Eigen2ToEigen3.html#Transform", null ],
        [ "Lazy evaluation and noalias", "Eigen2ToEigen3.html#LazyVsNoalias", null ],
        [ "Alignment-related macros", "Eigen2ToEigen3.html#AlignMacros", null ],
        [ "Aligned Map objects", "Eigen2ToEigen3.html#AlignedMap", null ],
        [ "STL Containers", "Eigen2ToEigen3.html#StdContainers", null ],
        [ "Internal ei_ prefix", "Eigen2ToEigen3.html#eiPrefix", null ]
      ] ],
      [ "Writing Functions Taking Eigen Types as Parameters", "TopicFunctionTakingEigenTypes.html", [
        [ "Some First Examples", "TopicFunctionTakingEigenTypes.html#TopicFirstExamples", null ],
        [ "How to write generic, but non-templated function?", "TopicFunctionTakingEigenTypes.html#TopicUsingRefClass", null ],
        [ "In which cases do functions taking plain Matrix or Array arguments work?", "TopicFunctionTakingEigenTypes.html#TopicPlainFunctionsWorking", null ],
        [ "In which cases do functions taking a plain Matrix or Array argument fail?", "TopicFunctionTakingEigenTypes.html#TopicPlainFunctionsFailing", null ],
        [ "How to resize matrices in generic implementations?", "TopicFunctionTakingEigenTypes.html#TopicResizingInGenericImplementations", null ],
        [ "Summary", "TopicFunctionTakingEigenTypes.html#TopicSummary", null ]
      ] ],
      [ "Preprocessor directives", "TopicPreprocessorDirectives.html", [
        [ "Macros with major effects", "TopicPreprocessorDirectives.html#TopicPreprocessorDirectivesMajor", null ],
        [ "C++ standard features", "TopicPreprocessorDirectives.html#TopicPreprocessorDirectivesCppVersion", null ],
        [ "Assertions", "TopicPreprocessorDirectives.html#TopicPreprocessorDirectivesAssertions", null ],
        [ "Alignment, vectorization and performance tweaking", "TopicPreprocessorDirectives.html#TopicPreprocessorDirectivesPerformance", null ],
        [ "Plugins", "TopicPreprocessorDirectives.html#TopicPreprocessorDirectivesPlugins", null ],
        [ "Macros for Eigen developers", "TopicPreprocessorDirectives.html#TopicPreprocessorDirectivesDevelopers", null ]
      ] ],
      [ "Assertions", "TopicAssertions.html", [
        [ "Assertions", "TopicAssertions.html#PlainAssert", [
          [ "Redefining assertions", "TopicAssertions.html#RedefineAssert", null ],
          [ "Disabling assertions", "TopicAssertions.html#DisableAssert", null ]
        ] ],
        [ "Static assertions", "TopicAssertions.html#StaticAssert", [
          [ "Derived static assertions", "TopicAssertions.html#DerivedStaticAssert", [
            [ "Strict assertions", "TopicAssertions.html#StrictAssertions", null ],
            [ "Permissive assertions", "TopicAssertions.html#PermissiveAssertions", null ]
          ] ],
          [ "Disabling static assertions", "TopicAssertions.html#DisableStaticAssert", null ]
        ] ]
      ] ],
      [ "Eigen and multi-threading", "TopicMultiThreading.html", [
        [ "Make Eigen run in parallel", "TopicMultiThreading.html#TopicMultiThreading_MakingEigenMT", null ],
        [ "Using Eigen in a multi-threaded application", "TopicMultiThreading.html#TopicMultiThreading_UsingEigenWithMT", null ]
      ] ],
      [ "Using BLAS/LAPACK from Eigen", "TopicUsingBlasLapack.html", null ],
      [ "Using Intel® MKL from Eigen", "TopicUsingIntelMKL.html", [
        [ "Links", "TopicUsingIntelMKL.html#TopicUsingIntelMKL_Links", null ]
      ] ],
      [ "Using Eigen in CUDA kernels", "TopicCUDA.html", null ],
      [ "Common pitfalls", "TopicPitfalls.html", [
        [ "Compilation error with template methods", "TopicPitfalls.html#TopicPitfalls_template_keyword", null ],
        [ "C++11 and the auto keyword", "TopicPitfalls.html#TopicPitfalls_auto_keyword", null ]
      ] ],
      [ "The template and typename keywords in C++", "TopicTemplateKeyword.html", [
        [ "Using the template and typename keywords to define templates", "TopicTemplateKeyword.html#TopicTemplateKeywordToDefineTemplates", null ],
        [ "An example showing the second use of the template keyword", "TopicTemplateKeyword.html#TopicTemplateKeywordExample", null ],
        [ "Explanation", "TopicTemplateKeyword.html#TopicTemplateKeywordExplanation", null ],
        [ "Resources for further reading", "TopicTemplateKeyword.html#TopicTemplateKeywordResources", null ]
      ] ],
      [ "Understanding Eigen", "UserManual_UnderstandingEigen.html", [
        [ "What happens inside Eigen, on a simple example", "TopicInsideEigenExample.html", [
          [ "Why it's interesting", "TopicInsideEigenExample.html#WhyInteresting", null ],
          [ "Constructing vectors", "TopicInsideEigenExample.html#ConstructingVectors", null ],
          [ "Construction of the sum expression", "TopicInsideEigenExample.html#ConstructionOfSumXpr", null ],
          [ "The assignment", "TopicInsideEigenExample.html#Assignment", null ]
        ] ],
        [ "The class hierarchy", "TopicClassHierarchy.html", [
          [ "Principles", "TopicClassHierarchy.html#TopicClassHierarchyPrinciples", null ],
          [ "The core classes", "TopicClassHierarchy.html#TopicClassHierarchyCoreClasses", null ],
          [ "Base classes", "TopicClassHierarchy.html#TopicClassHierarchyBaseClasses", null ],
          [ "Inheritance diagrams", "TopicClassHierarchy.html#TopicClassHierarchyInheritanceDiagrams", null ]
        ] ],
        [ "Lazy Evaluation and Aliasing", "TopicLazyEvaluation.html", null ]
      ] ]
    ] ],
    [ "Class List", "annotated.html", "annotated" ]
  ] ]
];

var NAVTREEINDEX =
[
"Eigen2ToEigen3.html"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';